@@ -177,7 +177,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
         context = self.contexts.get("default")
 
         page = await context.new_page()
-        await stealth_async(page, logger)
+        await stealth_async(page)
         self.stats.inc_value("playwright/page_count")
         logger.debug(
             "[Context=%s] New page created, page count is %i (%i for all contexts)",
